@@ -27,9 +27,4 @@ FILE_FIELD_BLACKLIST = [
     'fields'
 ]
 
-MINIMUM_REPO_VERSION = 5
 CURRENT_REPO_VERSION = 5
-
-VERSION_CEILINGS = {
-    4: '6.0'
-}
