@@ -11,13 +11,14 @@ import textwrap
 from jira.resources import Issue
 import six
 from six.moves.urllib import parse
+from six.moves import input
 
 from . import constants
 from . import exceptions
 from . import migrations
 from .decorators import stash_local_changes
 from .jirafieldmanager import JiraFieldManager
-from .utils import get_default_jira_server
+from .utils import get_default_jira_server, convert_to_boolean
 
 
 logger = logging.getLogger(__name__)
@@ -681,42 +682,30 @@ class TicketFolder(object):
 
         return status
 
-    @stash_local_changes
     def run_migrations(self, init=False):
         loglevel = logging.INFO
         if init:
             loglevel = logging.DEBUG
         else:
-            if self.version < constants.MINIMUM_REPO_VERSION:
-                version = self.version
-                # Find the latest version able to open this file.
-                while version < constants.CURRENT_REPO_VERSION:
-                    if version in constants.VERSION_CEILINGS:
-                        maximum_version = constants.VERSION_CEILINGS[version]
-                    # We might not have a mapping for this exact repo
-                    # version, but we may for one of the versions after it
-                    version += 1
+            if self.version < constants.CURRENT_REPO_VERSION:
                 print(
-                    "This ticket folder is too old for the version of "
-                    "Jirafs you are using.\nPlease either use Jirafs version "
-                    "%s for accessing this ticket folder, or delete and "
-                    "re-clone this ticket folder using `jirafs clone %s`." % (
-                        maximum_version,
-                        self.ticket_number
-                    )
+                    "Your ticket folder is out-of-date and must be updated."
+                    "Migrations are not necessarily lossless; please record "
+                    "your current changes before proceeding with migrations."
                 )
-                sys.exit(1)
-
+                result = convert_to_boolean(input("Proceed? (N/y)"))
+                if not result:
+                    sys.exit(1)
         while self.version < constants.CURRENT_REPO_VERSION:
             migrator = getattr(
                 migrations,
                 'migration_%s' % str(self.version + 1).zfill(4)
             )
-            self.migrate(migrator, loglevel=loglevel)
+            self.migrate(migrator, loglevel=loglevel, init=init)
 
-    def migrate(self, migrator, loglevel=logging.INFO):
+    def migrate(self, migrator, loglevel=logging.INFO, init=False):
         self.log('%s: Migration started', (migrator.__name__, ), loglevel)
-        migrator(self)
+        migrator(self, init=init)
         self.log('%s: Migration finished', (migrator.__name__, ), loglevel)
 
     def log(self, message, args=None, level=logging.INFO):
